@@ -344,7 +344,7 @@ def download_artifact():
 
 
 def login(key: str) -> (bool, str):
-    rsp = http_interface.login(get_http_host(), key, get_use_https())
+    rsp = http_interface.login(get_http_host(), key)
     if rsp["result"] == "success":
 
         grpc_url = get_grpc_host()
